lmgrd(1)

lmgrd - flexible license manager daemon

As shipped in IRIX 6.5.19. Last changed in IRIX 6.5.15.

NAME
     lmgrd - flexible license manager daemon

SYNOPSIS
     lmgrd [ -2 ] [ -b ] [ -c license_file ] [ -l logfile ] [ -p ] [ -s
     interval ] [ -t timeout ]

DESCRIPTION
     lmgrd is the main daemon program for the FLEXlm distributed license
     management system.  When invoked, it looks for a license file containing
     all required information about vendors and features.

OPTIONS
     -2        Specifies V2 startup arguments.  This is the opposite of the -b
               switch.  Note that -2 switch is REQUIRED if you intend to use
               the -p switch.  (Available in lmgrd v2.4 and later.)

     -b        Specifies backward compatibility mode.  Use this switch if you
               are running a v2.1 or later lmgrd with a v1.5 or earlier vendor
               daemon.  Note that in FLEXlm v2.4 or later the -b switch is the
               default.

     -c license_file
               Use the specified license_file.  If this switch is not
               specified, lmgrd looks for the environment variable
               LM_LICENSE_FILE.  If that environment variable is not set,
               lmgrd looks for the file
               /usr/local/flexlm/licenses/license.dat.

     -l logfile
               Specifies the output log file to use.

     -p        Specifies that the lmdown and lmremove utilities can only be
               run by a "license administrator". A "license administrator" is
               a member of the lmadmin group, or, if the lmadmin group does
               not exist, then a member of group 0.  (Available in lmgrd v2.4
               and later.)

     -s interval
               Specifies the logfile timestamp interval, in minutes.  The
               default is 360 minutes.

     -t timeout
               Specifies the timeout interval, in seconds, during which
               daemons must complete their connections to each other.  The
               default value is 10 seconds.  A larger value may be desirable
               if the daemons are being run on busy systems or a very heavily
               loaded network.
ENVIRONMENT
     If no -c option is specified, lmgrd looks for the environment variable
     LM_LICENSE_FILE in order to find the license file to use.  If that
     environment variable is not set, lmgrd looks for the file
     /usr/local/flexlm/licenses/license.dat.

NOTES
     IRIX systems typically install licenses in /var/flexlm/license.dat, not
     in /usr/local/flexlm/licenses/license.dat.

SEE ALSO
     lmdown(1), lmstat(1)